@@ -5,10 +5,11 @@
 
 	serif: "serif",
 	"sans-serif": "sans-serif",
-	monospaced: "monospaced",
+	monospace: "monospace",
 	cursive: "cursive",
 	fantasy: "fantasy",
 
+	noFormat: "Žádný",
 	p: "Odstavec",
 	h1: "Nadpis",
 	h2: "Podnadpis",
@@ -22,4 +23,4 @@
 	5: "velké",
 	6: "velmi velké",
 	7: "extra velké"
-})
\ No newline at end of file
+})
