@@ -13,26 +13,27 @@
  * to license@zend.com so we can send you a copy immediately.
  *
  * @category   Zend
- * @package    UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @package    Zend
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 8064 2008-02-16 10:58:39Z thomas $
+ * @version    $Id$
  */
 
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'AllTests::main');
 }
 
-/**
- * Test helper
- */
-require_once 'TestHelper.php';
-
-/**
- * @see Zend_AllTests
- */
 require_once 'Zend/AllTests.php';
+require_once 'resources/AllTests.php';
 
+/**
+ * @category   Zend
+ * @package    Zend
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ */
 class AllTests
 {
     public static function main()
@@ -48,14 +49,46 @@ class AllTests
             setlocale(LC_ALL, TESTS_ZEND_LOCALE_FORMAT_SETLOCALE);
         }
 
+        // Run buffered tests as a separate suite first
+        ob_start();
+        PHPUnit_TextUI_TestRunner::run(self::suiteBuffered(), $parameters);
+        if (ob_get_level()) {
+            ob_end_flush();
+        }
+
         PHPUnit_TextUI_TestRunner::run(self::suite(), $parameters);
     }
 
+    /**
+     * Buffered test suites
+     *
+     * These tests require no output be sent prior to running as they rely
+     * on internal PHP functions.
+     *
+     * @return PHPUnit_Framework_TestSuite
+     */
+    public static function suiteBuffered()
+    {
+        $suite = new PHPUnit_Framework_TestSuite('Zend Framework - Buffered');
+
+        $suite->addTest(Zend_AllTests::suiteBuffered());
+
+        return $suite;
+    }
+
+    /**
+     * Regular suite
+     *
+     * All tests except those that require output buffering.
+     *
+     * @return PHPUnit_Framework_TestSuite
+     */
     public static function suite()
     {
         $suite = new PHPUnit_Framework_TestSuite('Zend Framework');
 
         $suite->addTest(Zend_AllTests::suite());
+        $suite->addTest(resources_AllTests::suite());
 
         return $suite;
     }
