@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: HttpTest.php 24842 2012-05-31 18:31:28Z rob $
+ * @version    $Id$
  */
 
 // Call Zend_Controller_Request_HttpTest::main() if this source file is executed directly.
@@ -31,7 +31,7 @@ require_once 'Zend/Controller/Request/Http.php';
  * @category   Zend
  * @package    Zend_Controller
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Controller
  * @group      Zend_Controller_Request
@@ -660,6 +660,22 @@ class Zend_Controller_Request_HttpTest extends PHPUnit_Framework_TestCase
         $this->assertFalse($this->_request->getHeader('X-No-Such-Thing'));
     }
 
+    /**
+     * @see https://www.ietf.org/rfc/rfc3875 (4.1.2. and 4.1.3.)
+     */
+    public function testGetContentHeadersOnPostRequest()
+    {
+        $_SERVER['REQUEST_METHOD'] = 'POST';
+        $_SERVER['CONTENT_LENGTH'] = 100;
+        $_SERVER['CONTENT_TYPE']   = 'application/x-www-form-urlencoded';
+
+        $this->assertEquals(100, $this->_request->getHeader('Content-Length'));
+        $this->assertEquals(
+            'application/x-www-form-urlencoded',
+            $this->_request->getHeader('Content-Type')
+        );
+    }
+
     public function testGetHeaderThrowsExceptionWithNoInput()
     {
         try {
