@@ -1,12 +1,29 @@
 <?php
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_Form
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id$
+ */
+
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Form_ElementTest::main');
 }
 
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
-// error_reporting(E_ALL);
-
 require_once 'Zend/Form/Element.php';
 
 require_once 'Zend/Config.php';
@@ -15,11 +32,20 @@ require_once 'Zend/Form.php';
 require_once 'Zend/Form/Decorator/Abstract.php';
 require_once 'Zend/Form/Decorator/HtmlTag.php';
 require_once 'Zend/Loader/PluginLoader.php';
+require_once 'Zend/Registry.php';
 require_once 'Zend/Translate.php';
 require_once 'Zend/Validate/NotEmpty.php';
 require_once 'Zend/Validate/EmailAddress.php';
 require_once 'Zend/View.php';
 
+/**
+ * @category   Zend
+ * @package    Zend_Form
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Form
+ */
 class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
 {
     public static function main()
@@ -30,6 +56,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
 
     public function setUp()
     {
+        Zend_Registry::_unsetInstance();
         Zend_Form::setDefaultTranslator(null);
 
         if (isset($this->error)) {
@@ -153,7 +180,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-2851
+     * @group ZF-2851
      */
     public function testSetNameShouldNotAllowEmptyString()
     {
@@ -284,7 +311,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-2862
+     * @group ZF-2862
      */
     public function testBreakChainOnFailureFlagsForExistingValidatorsRemainSetWhenNotEmptyValidatorAutoInserted()
     {
@@ -431,12 +458,25 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         );
         $this->element->setAttribs($attribs);
 
-        $attribs['helper'] = 'formText';
-
         $received = $this->element->getAttribs();
         $this->assertEquals($attribs, $received);
     }
 
+    /**
+     * @group ZF-6061
+     */
+    public function testHelperDoesNotShowUpInAttribs()
+    {
+        $attribs = array(
+            'foo' => 'bar',
+            'bar' => 'baz',
+            'baz' => 'bat'
+        );
+        $this->element->setAttribs($attribs);
+
+        $this->assertFalse(array_key_exists('helper', $this->element->getAttribs()));
+    }
+
     public function testPassingNullValuesToSetAttribsUnsetsAttribs()
     {
         $this->testSetAttribsSetsMultipleAttribs();
@@ -700,7 +740,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $this->element->addValidators(array(
             'NotEmpty',
             'Alnum',
-            'Digits', 
+            'Digits',
         ));
 
         $validator  = $this->element->getValidator('Alnum');
@@ -773,8 +813,8 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $this->_checkZf2794();
 
         $message = 'My custom empty message';
-        $this->element->setRequired(true)
-                      ->addValidator('notEmpty', false, array('messages' => $message));
+        $this->element->addValidator('notEmpty', false, array('messages' => $message))
+                      ->setRequired(true);
 
         $this->element->isValid('');
         $messages = $this->element->getMessages();
@@ -797,7 +837,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $messages = $this->element->getMessages();
         $found    = false;
         foreach ($messages as $key => $message) {
-            if ($key == 'stringEmpty') {
+            if ($key == 'digitsStringEmpty') {
                 $found = true;
                 break;
             }
@@ -819,7 +859,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     }
 
     /**#@+
-     * @see ZF-2988
+     * @group ZF-2988
      */
     public function testSettingErrorMessageShouldOverrideValidationErrorMessages()
     {
@@ -1147,7 +1187,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $this->element->addFilters(array(
             'Alpha',
             'Alnum',
-            'Digits', 
+            'Digits',
         ));
 
         $filter  = $this->element->getFilter('Alnum');
@@ -1178,7 +1218,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
 
     public function testShouldUseFilterConstructorOptionsAsPassedToAddFilter()
     {
-        $this->element->addFilter('HtmlEntities', array('quoteStyle' => ENT_QUOTES, 'charSet' => 'UTF-8'));
+        $this->element->addFilter('HtmlEntities', array(array('quotestyle' => ENT_QUOTES, 'charset' => 'UTF-8')));
         $filter = $this->element->getFilter('HtmlEntities');
         $this->assertTrue($filter instanceof Zend_Filter_HtmlEntities);
         $this->assertEquals(ENT_QUOTES, $filter->getQuoteStyle());
@@ -1261,6 +1301,55 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $this->assertTrue($decorator instanceof Zend_Form_Decorator_ViewHelper);
     }
 
+    /**
+     * @group ZF-4822
+     */
+    public function testErrorsDecoratorRegisteredByDefault()
+    {
+        $this->_checkZf2794();
+
+        $decorator = $this->element->getDecorator('errors');
+        $this->assertTrue($decorator instanceof Zend_Form_Decorator_Errors);
+    }
+
+    /**
+     * @group ZF-4822
+     */
+    public function testDescriptionDecoratorRegisteredByDefault()
+    {
+        $this->_checkZf2794();
+
+        $decorator = $this->element->getDecorator('description');
+        $this->assertTrue($decorator instanceof Zend_Form_Decorator_Description);
+        $options = $decorator->getOptions();
+        $this->assertTrue(array_key_exists('tag', $options));
+        $this->assertEquals('p', $options['tag']);
+        $this->assertTrue(array_key_exists('class', $options));
+        $this->assertEquals('description', $options['class']);
+    }
+
+    /**
+     * @group ZF-4822
+     */
+    public function testHtmlTagDecoratorRegisteredByDefault()
+    {
+        $this->_checkZf2794();
+
+        $decorator = $this->element->getDecorator('HtmlTag');
+        $this->assertTrue($decorator instanceof Zend_Form_Decorator_HtmlTag);
+    }
+
+    /**
+     * @group ZF-4822
+     */
+    public function testLabelDecoratorRegisteredByDefault()
+    {
+        $this->_checkZf2794();
+
+        $decorator = $this->element->getDecorator('Label');
+        $this->assertTrue($decorator instanceof Zend_Form_Decorator_Label);
+    }
+
     public function testCanDisableRegisteringDefaultDecoratorsDuringInitialization()
     {
         $element = new Zend_Form_Element('foo', array('disableLoadDefaultDecorators' => true));
@@ -1307,7 +1396,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-3597
+     * @group ZF-3597
      */
     public function testAddingConcreteDecoratorShouldHonorOrder()
     {
@@ -1371,7 +1460,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-3069
+     * @group ZF-3069
      */
     public function testRemovingNamedDecoratorsShouldWork()
     {
@@ -1438,7 +1527,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
     }
 
     /**
-     * @see ZF-3376
+     * @group ZF-3376
      */
     public function testSetDecoratorsShouldAcceptReturnOfGetDecorators()
     {
@@ -1614,7 +1703,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
 
         $options = $this->getOptions();
         $options['validators'] = array(
-            array('notEmpty', true, array('bar')),
+            array('notEmpty', true, array(Zend_Validate_NotEmpty::ALL)),
             array('digits', true, array('bar')),
         );
         $this->element->setOptions($options);
@@ -1633,7 +1722,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $options = $this->getOptions();
         $options['validators'] = array(
             array(
-                'options'             => array('bar'),
+                'options'             => array(Zend_Validate_NotEmpty::ALL),
                 'breakChainOnFailure' => true,
                 'validator'           => 'notEmpty',
             ),
@@ -1671,12 +1760,12 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
 
         $options = $this->getOptions();
         $options['filters'] = array(
-            array('StringToUpper', array('bar' => 'baz')),
+            array('Digits', array('bar' => 'baz')),
             array('Alpha', array('foo')),
         );
         $this->element->setOptions($options);
-        $filter = $this->element->getFilter('StringToUpper');
-        $this->assertTrue($filter instanceof Zend_Filter_StringToUpper);
+        $filter = $this->element->getFilter('Digits');
+        $this->assertTrue($filter instanceof Zend_Filter_Digits);
         $filter = $this->element->getFilter('Alpha');
         $this->assertTrue($filter instanceof Zend_Filter_Alpha);
     }
@@ -1689,7 +1778,7 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $options['filters'] = array(
             array(
                 'options' => array('baz'),
-                'filter'  => 'StringToUpper'
+                'filter'  => 'Digits'
             ),
             array(
                 'options' => array('foo'),
@@ -1697,8 +1786,8 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
             ),
         );
         $this->element->setOptions($options);
-        $filter = $this->element->getFilter('StringToUpper');
-        $this->assertTrue($filter instanceof Zend_Filter_StringToUpper);
+        $filter = $this->element->getFilter('Digits');
+        $this->assertTrue($filter instanceof Zend_Filter_Digits);
         $filter = $this->element->getFilter('Alpha');
         $this->assertTrue($filter instanceof Zend_Filter_Alpha);
     }
@@ -1861,6 +1950,14 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $this->assertFalse($this->element->isValid('    '));
     }
 
+    public function testTranslatedLabel()
+    {
+        $this->element->setLabel('FooBar');
+        $translator = new Zend_Translate('array', array('FooBar' => 'BazBar'));
+        $this->element->setTranslator($translator);
+        $this->assertEquals('BazBar', $this->element->getLabel());
+    }
+
     // Extensions
 
     public function testInitCalledBeforeLoadDecorators()
@@ -1898,6 +1995,32 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
         $html = $this->element->bogusMethodCall();
     }
 
+    /**
+     * @group ZF-5150
+     */
+    public function testMarkingAsErrorShouldCauseIsErrorToReturnFalse()
+    {
+        $this->element->setValue('foo');
+        $this->element->markAsError();
+        $this->assertFalse($this->element->isValid('foo'));
+    }
+
+    /**
+     * @group ZF-4915
+     */
+    public function testElementShouldAllowSettingDefaultErrorMessageSeparator()
+    {
+        $this->element->setErrorMessageSeparator('|');
+        $this->assertEquals('|', $this->element->getErrorMessageSeparator());
+    }
+
+    /**
+     * @group ZF-4915
+     */
+    public function testElementShouldUseSemicolonAndSpaceAsDefaultErrorMessageSeparator()
+    {
+        $this->assertEquals('; ', $this->element->getErrorMessageSeparator());
+    }
 
     /**
      * Used by test methods susceptible to ZF-2794, marks a test as incomplete
@@ -1911,6 +2034,216 @@ class Zend_Form_ElementTest extends PHPUnit_Framework_TestCase
             $this->markTestIncomplete('Error occurs for PHP 5.1.4 on Windows');
         }
     }
+
+    /**
+     * @ZF-8882
+     */
+    public function testErrorMessagesShouldNotBeTranslatedWhenTranslatorIsDisabled()
+    {
+        $translations = array(
+            'foo' => 'Foo message',
+        );
+        $translate = new Zend_Translate('array', $translations);
+        $this->element->setTranslator($translate)
+                      ->addErrorMessage('foo')
+                      ->addValidator('Alpha');
+        $this->assertFalse($this->element->isValid(123));
+        $messages = $this->element->getMessages();
+        $this->assertEquals(1, count($messages));
+        $this->assertEquals('Foo message', array_shift($messages));
+
+        $this->element->setDisableTranslator(true);
+        $this->assertFalse($this->element->isValid(123));
+        $messages = $this->element->getMessages();
+        $this->assertEquals(1, count($messages));
+        $this->assertEquals('foo', array_shift($messages));
+    }
+
+    /**
+     * @group ZF-9275
+     */
+    public function testElementDoesntOverrideDefaultValidatorTranslatorWithDefaultRegistryTranslator()
+    {
+        $registryTranslations = array('alphaInvalid' => 'Registry message');
+        $registryTranslate = new Zend_Translate('array', $registryTranslations);
+        Zend_Registry::set('Zend_Translate', $registryTranslate);
+
+        $validatorTranslations = array('alphaInvalid' => 'Validator message');
+        $validatorTranslate = new Zend_Translate('array', $validatorTranslations);
+        Zend_Validate_Abstract::setDefaultTranslator($validatorTranslate);
+
+        $elementTranslations = array('alphaInvalid' => 'Element message');
+        $elementTranslate = new Zend_Translate('array', $elementTranslations);
+
+        // the default validate translator should beat the registry one
+        $this->element->addValidator('Alpha');
+        $this->assertFalse($this->element->isValid(123));
+        $messages = $this->element->getMessages();
+        $this->assertEquals('Validator message', $messages['alphaInvalid']);
+    }
+
+    /**
+     * @group ZF-9275
+     */
+    public function testDefaultTranslatorDoesntOverrideElementTranslatorOnValdiation()
+    {
+        $registryTranslations = array('alphaInvalid' => 'Registry message');
+        $registryTranslate = new Zend_Translate('array', $registryTranslations);
+        Zend_Registry::set('Zend_Translate', $registryTranslate);
+
+        $validatorTranslations = array('alphaInvalid' => 'Validator message');
+        $validatorTranslate = new Zend_Translate('array', $validatorTranslations);
+        Zend_Validate_Abstract::setDefaultTranslator($validatorTranslate);
+
+        $elementTranslations = array('alphaInvalid' => 'Element message');
+        $elementTranslate = new Zend_Translate('array', $elementTranslations);
+
+        $this->element->addValidator('Alpha');
+        $this->element->setTranslator($elementTranslate);
+        $this->assertFalse($this->element->isValid(123));
+        $messages = $this->element->getMessages();
+        $this->assertEquals('Element message', $messages['alphaInvalid']);
+    }
+
+    /**
+     * @group ZF-9275
+     */
+    public function testValidatorsDefaultTranslatorDoesntOverrideFormsDefaultTranslator()
+    {
+        $formTranslations = array('alphaInvalid' => 'Form message');
+        $formTranslate = new Zend_Translate('array', $formTranslations);
+        Zend_Form::setDefaultTranslator($formTranslate);
+
+        $validatorTranslations = array('alphaInvalid' => 'Validator message');
+        $validatorTranslate = new Zend_Translate('array', $validatorTranslations);
+        Zend_Validate_Abstract::setDefaultTranslator($validatorTranslate);
+
+        // the default validate translator should beat the registry one
+        $this->element->addValidator('Alpha');
+        $this->assertFalse($this->element->isValid(123));
+        $messages = $this->element->getMessages();
+        $this->assertEquals('Form message', $messages['alphaInvalid']);
+    }
+
+    /**
+     * @group ZF-9275
+     */
+    public function testElementsTranslatorDoesntOverrideValidatorsDirectlyAttachedTranslator()
+    {
+        $elementTranslations = array('alphaInvalid' => 'Element message');
+        $elementTranslate = new Zend_Translate('array', $elementTranslations);
+
+        $validatorTranslations = array('alphaInvalid' => 'Direct validator message');
+        $validatorTranslate = new Zend_Translate('array', $validatorTranslations);
+
+        $validator = new Zend_Validate_Alpha();
+        $validator->setTranslator($validatorTranslate);
+        $this->element->addValidator($validator);
+        $this->assertFalse($this->element->isValid(123));
+        $messages = $this->element->getMessages();
+        $this->assertEquals('Direct validator message', $messages['alphaInvalid']);
+    }
+
+    /**
+     * Prove the fluent interface on Zend_Form::loadDefaultDecorators
+     *
+     * @link http://framework.zend.com/issues/browse/ZF-9913
+     * @return void
+     */
+    public function testFluentInterfaceOnLoadDefaultDecorators()
+    {
+        $this->assertSame($this->element, $this->element->loadDefaultDecorators());
+    }
+
+    /**
+     * @group ZF-7552
+     */
+    public function testAddDecoratorsKeepsNonNumericKeyNames()
+    {
+        $this->element->addDecorators(array(array(array('td'  => 'HtmlTag'),
+                                               array('tag' => 'td')),
+                                         array(array('tr'  => 'HtmlTag'),
+                                               array('tag' => 'tr')),
+                                         array('HtmlTag', array('tag' => 'baz'))));
+        $t1 = $this->element->getDecorators();
+        $this->element->setDecorators($t1);
+        $t2 = $this->element->getDecorators();
+        $this->assertEquals($t1, $t2);
+    }
+
+    /**
+     * Check array notation for validators
+     */
+    public function testValidatorsGivenArrayKeysOnValidation()
+    {
+        $username = new Zend_Form_Element('username');
+        $username->addValidator('stringLength', true, array('min' => 5, 'max' => 20, 'ignore' => 'something'));
+        $form = new Zend_Form(array('elements' => array($username)));
+        $this->assertTrue($form->isValid(array('username' => 'abcde')));
+    }
+
+    /**
+     * @group ZF-6822
+     */
+    public function testValidatorByUsingStringNotation()
+    {
+        $this->_checkZf2794();
+
+        $username = new Zend_Form_Element('username');
+        $username->addValidator('stringLength', true, array(5, 20))
+                 ->addValidator('regex', true, '/^[a-zA-Z0-9_]*$/')
+                 ->addFilter('StringToLower')
+                 ->setRequired(true);
+        $form = new Zend_Form(array('elements' => array($username)));
+        $form->isValid(array('username' => '#'));
+
+        $validator = $username->getValidator('stringLength');
+        $this->assertTrue($validator->zfBreakChainOnFailure);
+        $validator = $username->getValidator('regex');
+        $this->assertTrue($validator->zfBreakChainOnFailure);
+    }
+    
+    /**
+     * @group ZF-12173
+     */
+    public function testCanAddPluginLoaderPrefixPathsWithBackslashes()
+    {
+        if (version_compare(PHP_VERSION, '5.3.0', '<')) {
+            $this->markTestSkipped(__CLASS__ . '::' . __METHOD__ . ' requires PHP 5.3.0 or greater');
+            return;
+        }
+        $validatorLoader = new Zend_Loader_PluginLoader();
+        $filterLoader    = new Zend_Loader_PluginLoader();
+        $decoratorLoader = new Zend_Loader_PluginLoader();
+        $this->element->setPluginLoader($validatorLoader, 'validate')
+                      ->setPluginLoader($filterLoader, 'filter')
+                      ->setPluginLoader($decoratorLoader, 'decorator')
+                      ->addPrefixPath('Zf\Foo', 'Zf/Foo');
+
+        $paths = $filterLoader->getPaths('Zf\Foo\Filter');
+        $this->assertTrue(is_array($paths));
+        $this->assertContains('Filter', $paths[0]);
+
+        $paths = $validatorLoader->getPaths('Zf\Foo\Validate');
+        $this->assertTrue(is_array($paths));
+        $this->assertContains('Validate', $paths[0]);
+
+        $paths = $decoratorLoader->getPaths('Zf\Foo\Decorator');
+        $this->assertTrue(is_array($paths), var_export($paths, 1));
+        $this->assertContains('Decorator', $paths[0]);
+    }
+
+    /**
+     * @group ZF-12439
+     */
+    public function testSettingAnEmptyArrayValueGeneratesAValidErrorMessage()
+    {
+        $this->element->setValue(array());
+        $this->element->addErrorMessage('Invalid value entered');
+        $this->element->markAsError();
+        $messages = $this->element->getMessages();
+        $this->assertEquals('Invalid value entered', array_shift($messages));
+    }
 }
 
 class Zend_Form_ElementTest_Decorator extends Zend_Form_Decorator_Abstract
