@@ -12,21 +12,24 @@
  * obtain it through the world-wide-web, please send an email
  * to license@zend.com so we can send you a copy immediately.
  *
- * @category     Zend
- * @package      Zend_Gdata
- * @subpackage   UnitTests
- * @copyright    Copyright (c) 2006 Zend Technologies USA Inc. (http://www.zend.com);
+ * @category   Zend
+ * @package    Zend_Gdata
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id $
  */
 
 require_once 'Zend/Gdata/Extension/FeedLink.php';
 require_once 'Zend/Gdata.php';
 
 /**
+ * @category   Zend
  * @package    Zend_Gdata
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Gdata
  */
 class Zend_Gdata_FeedLinkTest extends PHPUnit_Framework_TestCase
 {
@@ -37,7 +40,7 @@ class Zend_Gdata_FeedLinkTest extends PHPUnit_Framework_TestCase
                 true);
         $this->feedLink = new Zend_Gdata_Extension_FeedLink();
     }
-    
+
     public function testEmptyFeedLinkShouldHaveNoExtensionElements() {
         $this->assertTrue(is_array($this->feedLink->extensionElements));
         $this->assertTrue(count($this->feedLink->extensionElements) == 0);
@@ -59,20 +62,20 @@ class Zend_Gdata_FeedLinkTest extends PHPUnit_Framework_TestCase
         $this->assertTrue(is_array($this->feedLink->extensionAttributes));
         $this->assertTrue(count($this->feedLink->extensionAttributes) == 0);
     }
-    
+
     public function testNormalFeedLinkShouldHaveNoExtensionElements() {
         $this->feedLink->href = "http://www.google.com/calendar/feeds/default/private/full";
         $this->feedLink->rel = "via";
         $this->feedLink->countHint = "5";
-        $this->feedLink->readOnly = "false";
-        
+        $this->feedLink->readOnly = false;
+
         $this->assertEquals("http://www.google.com/calendar/feeds/default/private/full", $this->feedLink->href);
         $this->assertEquals("via", $this->feedLink->rel);
         $this->assertEquals("5", $this->feedLink->countHint);
-        $this->assertEquals("false", $this->feedLink->readOnly);
-                
+        $this->assertEquals(false, $this->feedLink->readOnly);
+
         $this->assertEquals(0, count($this->feedLink->extensionElements));
-        $newFeedLink = new Zend_Gdata_Extension_FeedLink(); 
+        $newFeedLink = new Zend_Gdata_Extension_FeedLink();
         $newFeedLink->transferFromXML($this->feedLink->saveXML());
         $this->assertEquals(0, count($newFeedLink->extensionElements));
         $newFeedLink->extensionElements = array(
@@ -81,7 +84,7 @@ class Zend_Gdata_FeedLinkTest extends PHPUnit_Framework_TestCase
         $this->assertEquals("http://www.google.com/calendar/feeds/default/private/full", $newFeedLink->href);
         $this->assertEquals("via", $newFeedLink->rel);
         $this->assertEquals("5", $newFeedLink->countHint);
-        $this->assertEquals("false", $newFeedLink->readOnly);
+        $this->assertEquals(false, $newFeedLink->readOnly);
 
         /* try constructing using magic factory */
         $gdata = new Zend_Gdata();
@@ -91,7 +94,7 @@ class Zend_Gdata_FeedLinkTest extends PHPUnit_Framework_TestCase
         $this->assertEquals("http://www.google.com/calendar/feeds/default/private/full", $newFeedLink2->href);
         $this->assertEquals("via", $newFeedLink2->rel);
         $this->assertEquals("5", $newFeedLink2->countHint);
-        $this->assertEquals("false", $newFeedLink2->readOnly);
+        $this->assertEquals(false, $newFeedLink2->readOnly);
     }
 
     public function testEmptyFeedLinkToAndFromStringShouldMatch() {
@@ -106,7 +109,7 @@ class Zend_Gdata_FeedLinkTest extends PHPUnit_Framework_TestCase
         $this->feedLink->href = "http://www.google.com/calendar/feeds/default/private/full";
         $this->feedLink->rel = "via";
         $this->feedLink->countHint = "5";
-        $this->feedLink->readOnly = "false";
+        $this->feedLink->readOnly = false;
         $feedLinkXml = $this->feedLink->saveXML();
         $newFeedLink = new Zend_Gdata_Extension_FeedLink();
         $newFeedLink->transferFromXML($feedLinkXml);
@@ -115,7 +118,7 @@ class Zend_Gdata_FeedLinkTest extends PHPUnit_Framework_TestCase
         $this->assertEquals("http://www.google.com/calendar/feeds/default/private/full", $this->feedLink->href);
         $this->assertEquals("via", $this->feedLink->rel);
         $this->assertEquals("5", $this->feedLink->countHint);
-        $this->assertEquals("false", $this->feedLink->readOnly);
+        $this->assertEquals(false, $this->feedLink->readOnly);
     }
 
     public function testExtensionAttributes() {
@@ -137,9 +140,9 @@ class Zend_Gdata_FeedLinkTest extends PHPUnit_Framework_TestCase
         $this->assertEquals("http://www.google.com/calendar/feeds/default/private/full/3tsi3ag1q40bnsik88k25sgpss/comments", $this->feedLink->href);
         $this->assertEquals("http://schemas.google.com/g/2005#feed", $this->feedLink->rel);
         $this->assertEquals("0", $this->feedLink->countHint);
-        $this->assertEquals("true", $this->feedLink->readOnly);
-		$this->assertTrue($this->feedLink->feed instanceof Zend_Gdata_App_Feed);
-		$this->assertEquals("Comments for: Sample Event", $this->feedLink->feed->title->text);
+        $this->assertEquals(true, $this->feedLink->readOnly);
+        $this->assertTrue($this->feedLink->feed instanceof Zend_Gdata_App_Feed);
+        $this->assertEquals("Comments for: Sample Event", $this->feedLink->feed->title->text);
     }
 
 }
