@@ -1,13 +1,30 @@
 <?php
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_Layout
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id$
+ */
+
 // Call Zend_Layout_LayoutTest::main() if this source file is executed directly.
 if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_Layout_LayoutTest::main");
 }
 
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
-
 require_once 'Zend/Layout.php';
 require_once 'Zend/Layout/Controller/Plugin/Layout.php';
 require_once 'Zend/Layout/Controller/Action/Helper/Layout.php';
@@ -19,8 +36,15 @@ require_once 'Zend/View.php';
 
 /**
  * Test class for Zend_Layout.
+ *
+ * @category   Zend
+ * @package    Zend_Layout
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Layout
  */
-class Zend_Layout_LayoutTest extends PHPUnit_Framework_TestCase 
+class Zend_Layout_LayoutTest extends PHPUnit_Framework_TestCase
 {
     /**
      * Runs the test methods of this class.
@@ -29,7 +53,6 @@ class Zend_Layout_LayoutTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_Layout_LayoutTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -43,7 +66,7 @@ class Zend_Layout_LayoutTest extends PHPUnit_Framework_TestCase
      */
     public function setUp()
     {
-        Zend_Layout_LayoutTest_Override::$_mvcInstance = null;
+        Zend_Layout_LayoutTest_Override::resetMvcInstance();
 
         Zend_Controller_Front::getInstance()->resetInstance();
         if (Zend_Controller_Action_HelperBroker::hasHelper('Layout')) {
@@ -62,6 +85,7 @@ class Zend_Layout_LayoutTest extends PHPUnit_Framework_TestCase
      */
     public function tearDown()
     {
+        Zend_Layout::resetMvcInstance();
     }
 
     public function testDefaultLayoutStatusAtInitialization()
@@ -471,7 +495,7 @@ class Zend_Layout_LayoutTest extends PHPUnit_Framework_TestCase
         $layout->setInflectorTarget('php');
         $this->assertEquals($layout->getInflectorTarget(), $inflector->getTarget());
     }
-    
+
     public function testLayoutWithViewBasePath()
     {
         $layout = new Zend_Layout(array(
@@ -481,7 +505,7 @@ class Zend_Layout_LayoutTest extends PHPUnit_Framework_TestCase
         $layout->setLayout('layout2');
         $this->assertEquals('foobar-helper-output', $layout->render());
     }
-    
+
     public function testResettingMvcInstanceUnregistersHelperAndPlugin()
     {
         $this->testGetMvcInstanceReturnsLayoutInstanceWhenStartMvcHasBeenCalled();
@@ -497,7 +521,7 @@ class Zend_Layout_LayoutTest extends PHPUnit_Framework_TestCase
         Zend_Layout::resetMvcInstance();
         $this->assertNull(Zend_Layout::getMvcInstance());
     }
-    
+
     public function testMinimalViewObjectWorks()
     {
         require_once dirname(__FILE__) . '/_files/MinimalCustomView.php';
@@ -507,7 +531,30 @@ class Zend_Layout_LayoutTest extends PHPUnit_Framework_TestCase
             ));
         $layout->render();
     }
-    
+
+    /**
+     * @group ZF-5152
+     */
+    public function testCallingStartMvcTwiceDoesntGenerateAnyUnexpectedBehavior()
+    {
+        Zend_Layout::startMvc('/some/path');
+        $this->assertEquals(Zend_Layout::getMvcInstance()->getLayoutPath(),'/some/path');
+        Zend_Layout::startMvc('/some/other/path');
+        $this->assertEquals(Zend_Layout::getMvcInstance()->getLayoutPath(),'/some/other/path');
+        $this->assertTrue(Zend_Layout::getMvcInstance()->isEnabled());
+    }
+
+    /**
+     * @group ZF-5891
+     */
+    public function testSetLayoutWithDisabledFlag()
+    {
+        $layout = new Zend_Layout();
+        $layout->disableLayout();
+        $layout->setLayout('foo', false);
+        $this->assertEquals('foo', $layout->getLayout());
+        $this->assertFalse($layout->isEnabled());
+    }
 }
 
 /**
@@ -515,7 +562,10 @@ class Zend_Layout_LayoutTest extends PHPUnit_Framework_TestCase
  */
 class Zend_Layout_LayoutTest_Override extends Zend_Layout
 {
-    public static $_mvcInstance;
+    public static function resetMvcInstance()
+    {
+        self::$_mvcInstance = null;
+    }
 }
 
 class Zend_Layout_LayoutTest_Controller_Plugin_Layout extends Zend_Layout_Controller_Plugin_Layout
