@@ -15,9 +15,9 @@
  * @category   Zend
  * @package    Zend_Rest
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: RouteTest.php 24593 2012-01-05 20:35:02Z matthew $
+ * @version    $Id$
  */
 
 /** Zend_Rest_Route */
@@ -38,7 +38,7 @@ if (!defined("PHPUnit_MAIN_METHOD")) {
  * @category   Zend
  * @package    Zend_Rest
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2012 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
  * @group      Zend_Rest
  */
@@ -98,7 +98,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
     	$router = new Zend_Controller_Router_Rewrite();
     	$router->addConfig($config, 'routes');
     	$route = $router->getRoute('rest');
-    	$this->assertType('Zend_Rest_Route', $route);
+    	$this->assertTrue($route instanceof Zend_Rest_Route);
     	$this->assertEquals('object', $route->getDefault('controller'));
 
     	$request = $this->_buildRequest('GET', '/mod/project');
@@ -123,7 +123,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('GET', '/');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('index', $values['controller']);
@@ -138,7 +138,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('GET', '/user');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -150,7 +150,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('GET', '/user/index');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -162,7 +162,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('GET', '/user/index/changedSince/123456789/status/active');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -176,7 +176,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('GET', '/user/?changedSince=123456789&status=active');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -193,7 +193,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('GET', '/user/index/the%2Bemail%40address/email%2Btest%40example.com');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -206,7 +206,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('GET', '/project/zendframework');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('project', $values['controller']);
@@ -219,7 +219,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('GET', '/project/?id=zendframework');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('project', $values['controller']);
@@ -232,7 +232,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('GET', '/project/zend+framework');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('project', $values['controller']);
@@ -248,7 +248,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('GET', '/project/email%2Btest%40example.com');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('project', $values['controller']);
@@ -261,7 +261,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('HEAD', '/project/lcrouch');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('project', $values['controller']);
@@ -276,7 +276,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('HEAD', '/project/email%2Btest%40example.com');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('project', $values['controller']);
@@ -289,7 +289,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('GET', '/project/zendframework/edit');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('project', $values['controller']);
@@ -305,7 +305,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('GET', '/project/email%2Btest%40example.com/edit');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('default', $values['module']);
         $this->assertEquals('project', $values['controller']);
@@ -318,7 +318,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('PUT', '/mod/user/lcrouch');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -334,7 +334,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('PUT', '/mod/user/email%2Btest%40example.com');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -347,7 +347,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('POST', '/mod/user');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -359,7 +359,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('DELETE', '/mod/user/lcrouch');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -375,7 +375,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('DELETE', '/mod/user/email%2Btest%40example.com');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -388,7 +388,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('POST', '/mod/user/lcrouch');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -404,7 +404,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request = $this->_buildRequest('POST', '/mod/user/email%2Btest%40example.com');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -418,7 +418,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request->setParam('_method', 'PUT');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -431,7 +431,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request->setHeader('X-HTTP-Method-Override', 'DELETE');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -448,7 +448,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $request->setHeader('X-HTTP-Method-Override', 'DELETE');
         $values = $this->_invokeRouteMatch($request);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -505,7 +505,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod');
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -521,7 +521,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod');
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -535,7 +535,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod');
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -551,7 +551,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod');
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -565,7 +565,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod');
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -587,7 +587,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod');
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -604,7 +604,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod');
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -618,7 +618,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod');
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -635,7 +635,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod');
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -649,7 +649,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod'=>array('user'));
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -680,7 +680,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod'=>array('user'));
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -696,7 +696,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod'=>array('user'));
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -710,7 +710,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod'=>array('user'));
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -750,7 +750,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod'=>array('user'));
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -767,7 +767,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod'=>array('user'));
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -781,7 +781,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod');
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
@@ -798,7 +798,7 @@ class Zend_Rest_RouteTest extends PHPUnit_Framework_TestCase
         $config = array('mod');
         $values = $this->_invokeRouteMatch($request, $config);
 
-        $this->assertType('array', $values);
+        $this->assertTrue(is_array($values));
         $this->assertTrue(isset($values['module']));
         $this->assertEquals('mod', $values['module']);
         $this->assertEquals('user', $values['controller']);
