@@ -1,16 +1,29 @@
 <?php
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_Search_Lucene
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id$
+ */
+
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Search_Lucene_AllTests::main');
 }
 
-/**
- * Test helper
- */
-require_once dirname(dirname(dirname(dirname(__FILE__)))) . DIRECTORY_SEPARATOR . 'TestHelper.php';
-
-require_once 'PHPUnit/Framework/TestSuite.php';
-require_once 'PHPUnit/TextUI/TestRunner.php';
-
 require_once 'Zend/Search/Lucene/LuceneTest.php';
 
 require_once 'Zend/Search/Lucene/DocumentTest.php';
@@ -22,7 +35,7 @@ require_once 'Zend/Search/Lucene/AnalysisTest.php';
 
 require_once 'Zend/Search/Lucene/Index/DictionaryLoaderTest.php';
 require_once 'Zend/Search/Lucene/Index/FieldInfoTest.php';
-require_once 'Zend/Search/Lucene/Index/SegmentInfoPriorityQueueTest.php';
+require_once 'Zend/Search/Lucene/Index/TermsPriorityQueueTest.php';
 require_once 'Zend/Search/Lucene/Index/SegmentInfoTest.php';
 require_once 'Zend/Search/Lucene/Index/SegmentMergerTest.php';
 require_once 'Zend/Search/Lucene/Index/TermInfoTest.php';
@@ -31,10 +44,20 @@ require_once 'Zend/Search/Lucene/Index/TermTest.php';
 require_once 'Zend/Search/Lucene/Storage/DirectoryTest.php';
 require_once 'Zend/Search/Lucene/Storage/FileTest.php';
 
+require_once 'Zend/Search/Lucene/SearchHighlightTest.php';
+
 require_once 'Zend/Search/Lucene/SearchTest.php';
 require_once 'Zend/Search/Lucene/Search23Test.php';
 
 
+/**
+ * @category   Zend
+ * @package    Zend_Search_Lucene
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Search_Lucene
+ */
 class Zend_Search_Lucene_AllTests
 {
     public static function main()
@@ -57,7 +80,7 @@ class Zend_Search_Lucene_AllTests
 
         $suite->addTestSuite('Zend_Search_Lucene_Index_DictionaryLoaderTest');
         $suite->addTestSuite('Zend_Search_Lucene_Index_FieldInfoTest');
-        $suite->addTestSuite('Zend_Search_Lucene_Index_SegmentInfoPriorityQueueTest');
+        $suite->addTestSuite('Zend_Search_Lucene_Index_TermsPriorityQueueTest');
         $suite->addTestSuite('Zend_Search_Lucene_Index_SegmentInfoTest');
         $suite->addTestSuite('Zend_Search_Lucene_Index_SegmentMergerTest');
         $suite->addTestSuite('Zend_Search_Lucene_Index_TermInfoTest');
@@ -70,6 +93,8 @@ class Zend_Search_Lucene_AllTests
         $suite->addTestSuite('Zend_Search_Lucene_Storage_DirectoryTest');
         $suite->addTestSuite('Zend_Search_Lucene_Storage_FileTest');
 
+        $suite->addTestSuite('Zend_Search_Lucene_SearchHighlightTest');
+
         $suite->addTestSuite('Zend_Search_Lucene_SearchTest');
         $suite->addTestSuite('Zend_Search_Lucene_Search23Test');
 
