@@ -1,26 +1,37 @@
 <?php
 /**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
  * @category   Zend
  * @package    Zend_Search_Lucene
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version    $Id$
  */
 
-
 /**
  * Zend_Search_Lucene
  */
 require_once 'Zend/Search/Lucene/Analysis/Analyzer.php';
 
-/**
- * PHPUnit test case
- */
-require_once 'PHPUnit/Framework/TestCase.php';
-
-
 /**
  * @category   Zend
  * @package    Zend_Search_Lucene
  * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Search_Lucene
  */
 class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
 {
@@ -29,6 +40,9 @@ class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
         $currentAnalyzer = Zend_Search_Lucene_Analysis_Analyzer::getDefault();
         $this->assertTrue($currentAnalyzer instanceof Zend_Search_Lucene_Analysis_Analyzer);
 
+        /** Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8Num */
+        require_once 'Zend/Search/Lucene/Analysis/Analyzer/Common/Utf8Num.php';
+
         $newAnalyzer = new Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8Num();
         Zend_Search_Lucene_Analysis_Analyzer::setDefault($newAnalyzer);
         $this->assertTrue(Zend_Search_Lucene_Analysis_Analyzer::getDefault() === $newAnalyzer);
@@ -39,6 +53,9 @@ class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
 
     public function testText()
     {
+        /** Zend_Search_Lucene_Analysis_Analyzer_Common_Text */
+        require_once 'Zend/Search/Lucene/Analysis/Analyzer/Common/Text.php';
+
         $analyzer = new Zend_Search_Lucene_Analysis_Analyzer_Common_Text();
 
         $tokenList = $analyzer->tokenize('Word1 Word2 anotherWord');
@@ -63,6 +80,9 @@ class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
 
     public function testTextCaseInsensitive()
     {
+        /** Zend_Search_Lucene_Analysis_Analyzer_Common_Text_CaseInsensitive */
+        require_once 'Zend/Search/Lucene/Analysis/Analyzer/Common/Text/CaseInsensitive.php';
+
         $analyzer = new Zend_Search_Lucene_Analysis_Analyzer_Common_Text_CaseInsensitive();
 
         $tokenList = $analyzer->tokenize('Word1 Word2 anotherWord');
@@ -87,6 +107,9 @@ class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
 
     public function testTextNum()
     {
+        /** Zend_Search_Lucene_Analysis_Analyzer_Common_TextNum */
+        require_once 'Zend/Search/Lucene/Analysis/Analyzer/Common/TextNum.php';
+
         $analyzer = new Zend_Search_Lucene_Analysis_Analyzer_Common_TextNum();
 
         $tokenList = $analyzer->tokenize('Word1 Word2 anotherWord');
@@ -111,6 +134,9 @@ class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
 
     public function testTextNumCaseInsensitive()
     {
+        /** Zend_Search_Lucene_Analysis_Analyzer_Common_TextNum_CaseInsensitive */
+        require_once 'Zend/Search/Lucene/Analysis/Analyzer/Common/TextNum/CaseInsensitive.php';
+
         $analyzer = new Zend_Search_Lucene_Analysis_Analyzer_Common_TextNum_CaseInsensitive();
 
         $tokenList = $analyzer->tokenize('Word1 Word2 anotherWord');
@@ -139,7 +165,10 @@ class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
             // PCRE unicode support is turned off
             return;
         }
-                
+
+        /** Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8 */
+        require_once 'Zend/Search/Lucene/Analysis/Analyzer/Common/Utf8.php';
+
         $analyzer = new Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8();
 
         // UTF-8 text with a cyrillic symbols
@@ -170,6 +199,9 @@ class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
             return;
         }
 
+        /** Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8Num */
+        require_once 'Zend/Search/Lucene/Analysis/Analyzer/Common/Utf8Num.php';
+
         $analyzer = new Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8Num();
 
         // UTF-8 text with a cyrillic symbols
@@ -204,6 +236,9 @@ class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
             return;
         }
 
+        /** Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8_CaseInsensitive */
+        require_once 'Zend/Search/Lucene/Analysis/Analyzer/Common/Utf8/CaseInsensitive.php';
+
         $analyzer = new Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8_CaseInsensitive();
 
         // UTF-8 text with a cyrillic symbols
@@ -237,7 +272,9 @@ class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
             // mbstring extension is disabled
             return;
         }
-        
+
+        /** Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8Num_CaseInsensitive */
+        require_once 'Zend/Search/Lucene/Analysis/Analyzer/Common/Utf8Num/CaseInsensitive.php';
         $analyzer = new Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8Num_CaseInsensitive();
 
         // UTF-8 text with a cyrillic symbols
@@ -263,6 +300,13 @@ class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
 
     public function testEncoding()
     {
+        if (PHP_OS == 'AIX') {
+            $this->markTestSkipped('Test not available on AIX');
+        }
+
+        /** Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8 */
+        require_once 'Zend/Search/Lucene/Analysis/Analyzer/Common/Utf8.php';
+
         $analyzer = new Zend_Search_Lucene_Analysis_Analyzer_Common_Utf8();
 
         // UTF-8 text with a cyrillic symbols
@@ -288,6 +332,12 @@ class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
 
     public function testStopWords()
     {
+        /** Zend_Search_Lucene_Analysis_Analyzer_Common_Text_CaseInsensitive */
+        require_once 'Zend/Search/Lucene/Analysis/Analyzer/Common/Text/CaseInsensitive.php';
+
+        /** Zend_Search_Lucene_Analysis_TokenFilter_StopWords */
+        require_once 'Zend/Search/Lucene/Analysis/TokenFilter/StopWords.php';
+
         $analyzer = new Zend_Search_Lucene_Analysis_Analyzer_Common_Text_CaseInsensitive();
         $stopWordsFilter = new Zend_Search_Lucene_Analysis_TokenFilter_StopWords(array('word', 'and', 'or'));
 
@@ -305,6 +355,12 @@ class Zend_Search_Lucene_AnalysisTest extends PHPUnit_Framework_TestCase
 
     public function testShortWords()
     {
+        /** Zend_Search_Lucene_Analysis_Analyzer_Common_Text_CaseInsensitive */
+        require_once 'Zend/Search/Lucene/Analysis/Analyzer/Common/Text/CaseInsensitive.php';
+
+        /** Zend_Search_Lucene_Analysis_TokenFilter_ShortWords */
+        require_once 'Zend/Search/Lucene/Analysis/TokenFilter/ShortWords.php';
+
         $analyzer = new Zend_Search_Lucene_Analysis_Analyzer_Common_Text_CaseInsensitive();
         $stopWordsFilter = new Zend_Search_Lucene_Analysis_TokenFilter_ShortWords(4 /* Minimal length */);
 
