@@ -1,5 +1,4 @@
 <?php
-
 /**
  * Zend Framework
  *
@@ -16,41 +15,25 @@
  * @category   Zend
  * @package    Zend_Session
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: AllTests.php 10116 2008-07-16 02:34:10Z matthew $
+ * @version    $Id$
  */
 
-
 if (!defined('PHPUnit_MAIN_METHOD')) {
     define('PHPUnit_MAIN_METHOD', 'Zend_Session_AllTests::main');
 }
 
-
-/**
- * Test helper
- */
-require_once dirname(__FILE__) . '/../../TestHelper.php';
-
-
-/**
- * Zend_Session tests need to be output buffered because they depend on headers_sent() === false
- *
- * @see http://framework.zend.com/issues/browse/ZF-700
- */
-ob_start();
-
 require_once 'SessionTest.php';
-
-/** Zend_Session_SaveHandler_AllTests */
 require_once 'Zend/Session/SaveHandler/AllTests.php';
 
 /**
  * @category   Zend
  * @package    Zend_Session
  * @subpackage UnitTests
- * @copyright  Copyright (c) 2005-2008 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_Session
  */
 class Zend_Session_AllTests
 {
@@ -61,11 +44,6 @@ class Zend_Session_AllTests
      */
     public static function main()
     {
-        /**
-         * PHPUnit_TextUI_TestRunner
-         */
-        require_once 'PHPUnit/TextUI/TestRunner.php';
-
         PHPUnit_TextUI_TestRunner::run(self::suite());
     }
 
@@ -76,14 +54,8 @@ class Zend_Session_AllTests
      */
     public static function suite()
     {
-        /**
-         * PHPUnit_Framework_TestSuite
-         */
-        require_once 'PHPUnit/Framework/TestSuite.php';
-
         $suite = new PHPUnit_Framework_TestSuite('Zend Framework - Zend_Session');
 
-
         $suite->addTestSuite('Zend_SessionTest');
         $suite->addTest(Zend_Session_SaveHandler_AllTests::suite());
 
