@@ -1,13 +1,30 @@
 <?php
+/**
+ * Zend Framework
+ *
+ * LICENSE
+ *
+ * This source file is subject to the new BSD license that is bundled
+ * with this package in the file LICENSE.txt.
+ * It is also available through the world-wide-web at this URL:
+ * http://framework.zend.com/license/new-bsd
+ * If you did not receive a copy of the license and are unable to
+ * obtain it through the world-wide-web, please send an email
+ * to license@zend.com so we can send you a copy immediately.
+ *
+ * @category   Zend
+ * @package    Zend_View
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @version $Id$
+ */
+
 // Call Zend_View_Helper_UrlTest::main() if this source file is executed directly.
 if (!defined("PHPUnit_MAIN_METHOD")) {
     define("PHPUnit_MAIN_METHOD", "Zend_View_Helper_UrlTest::main");
 }
 
-require_once dirname(dirname(dirname(dirname(__FILE__)))) . '/TestHelper.php';
-require_once "PHPUnit/Framework/TestCase.php";
-require_once "PHPUnit/Framework/TestSuite.php";
-
 require_once 'Zend/View.php';
 require_once 'Zend/View/Helper/Url.php';
 
@@ -17,14 +34,19 @@ require_once 'Zend/Controller/Front.php';
 require_once 'Zend/Controller/Request/Http.php';
 
 /**
- * Zend_View_Helper_UrlTest 
+ * Zend_View_Helper_UrlTest
  *
  * Tests formText helper, including some common functionality of all form helpers
- * 
- * @uses PHPUnit_Framework_TestCase
- * @version $Id: UrlTest.php 4828 2007-05-16 21:28:54Z matthew $
+ *
+ * @category   Zend
+ * @package    Zend_View
+ * @subpackage UnitTests
+ * @copyright  Copyright (c) 2005-2015 Zend Technologies USA Inc. (http://www.zend.com)
+ * @license    http://framework.zend.com/license/new-bsd     New BSD License
+ * @group      Zend_View
+ * @group      Zend_View_Helper
  */
-class Zend_View_Helper_UrlTest extends PHPUnit_Framework_TestCase 
+class Zend_View_Helper_UrlTest extends PHPUnit_Framework_TestCase
 {
     /**
      * Runs the test methods of this class.
@@ -34,7 +56,6 @@ class Zend_View_Helper_UrlTest extends PHPUnit_Framework_TestCase
      */
     public static function main()
     {
-        require_once "PHPUnit/TextUI/TestRunner.php";
 
         $suite  = new PHPUnit_Framework_TestSuite("Zend_View_Helper_UrlTest");
         $result = PHPUnit_TextUI_TestRunner::run($suite);
@@ -67,7 +88,7 @@ class Zend_View_Helper_UrlTest extends PHPUnit_Framework_TestCase
         $url = $this->helper->url(array('controller' => 'ctrl', 'action' => 'act'));
         $this->assertEquals('/ctrl/act', $url);
     }
-    
+
 }
 
 // Call Zend_View_Helper_UrlTest::main() if this source file is executed directly.
